# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "authentik-client"
VERSION = "2025.10.0-rc1-1756848917"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
    "lazy-imports >= 1, < 2",
]

setup(
    name=NAME,
    version=VERSION,
    description="authentik",
    author="authentik Team",
    author_email="hello@goauthentik.io",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "authentik"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    Making authentication simple.
    """,  # noqa: E501
    package_data={"authentik_client": ["py.typed"]},
)